import pandas as pd
import matplotlib.pyplot as plt
import matplotlib.dates as mdates
import numpy as np
import re
import glob
import os
import datetime
import matplotlib.patches as mpatches

# 最新ファイルの取得(_num.xlsxがあるもの)
file_list=glob.glob('*_num.xlsx')
print(file_list)
file_updates = {file_path: os.stat(file_path).st_mtime for file_path in file_list}
newest_file_path = max(file_updates, key=file_updates.get)
base=newest_file_path[:-5]
print(base)

# ヘッダ取得
df_header=pd.read_excel(f'{base}.xlsx', sheet_name=0, skiprows=0, nrows=3, usecols=[0,1], index_col=0, header=None)
print(df_header)
character=df_header.at['character',1]
years_old=df_header.at['yo',1]
date_event=df_header.at['date',1]

df=pd.read_excel(f'{base}.xlsx', sheet_name=0, skiprows=4, parse_dates=['start_time','end_time']).fillna(0)
df.set_index('start_time', inplace=True, drop=False)
start_time=df['start_time'][0]
xlim_start=  start_time.replace(hour=0, minute=0, second=0, microsecond=0)
xlim_end = xlim_start + datetime.timedelta(days=1, minutes=10)

df=pd.concat([df, pd.DataFrame([pd.Series([0, xlim_start, xlim_start, xlim_start, '', '', '', '', 0, 0, 0, 0, 0, 0, 0], index=df.columns, name=xlim_start)])], ignore_index=True)
df=df.sort_index()
df['amount_total']=df.loc[:,'amount_omo':'amount_toilet'].sum(axis=1)

# data整形
x=[]
y1=[]
y2=[]
y3=[]
y4=[]
for i,row in df.iterrows():
    if row['amount_total'] > 0:
        x.append(row['start_time'])
        y1.append(row['amount_omo'])
        y2.append(row['amount_omo']+row['amount_out'])
        y3.append(row['amount_omo']+row['amount_out']+row['amount_field'])
        y4.append(row['amount_omo']+row['amount_out']+row['amount_field']+row['amount_toilet'])
        x.append(row['end_time'])
        y1.append(0.0)
        y2.append(0.0)
        y3.append(0.0)
        y4.append(0.0)
print(len(x),x)
print(len(y3),y3)
plt.xlim(xlim_start, xlim_end)
plt.ylim(0,int((df['amount_total'].max()+100.0)/100.0)*100.0)
plt.xlabel('時刻',fontname="Meiryo")
plt.ylabel('1回あたりの排泄量 [g]',fontname="Meiryo")
plt.title(f'{character}({years_old}歳) {date_event:%Y/%m/%d}',fontname="Meiryo")
plt.gca().xaxis.set_major_formatter(mdates.DateFormatter('%#H'))
plt.gca().xaxis.set_major_locator(mdates.HourLocator(interval=1))
plt.fill_between(x,y4, step="post", color='brown',alpha=1.0)
plt.fill_between(x,y3, step="post", color='green',alpha=1.0)
plt.fill_between(x,y2, step="post", color='orange',alpha=1.0)
plt.fill_between(x,y1, step="post", color='red',alpha=1.0)

omo_patch = mpatches.Patch(color='red', label='おもらし')
out_patch = mpatches.Patch(color='orange', label='脱ぎかけ')
field_patch = mpatches.Patch(color='green', label='野外排泄')
toilet_patch = mpatches.Patch(color='brown', label='トイレ')
plt.legend(handles=[toilet_patch, field_patch, out_patch, omo_patch],prop={"family":"Meiryo"}, loc='upper left')

plt.savefig(f'{base}.png',dpi=100, bbox_inches='tight')

with open(f'{base}.txt','w') as f:
    for n, (index,row) in enumerate(df.iterrows()):
#        if n==0:
#            continue
        td_seconds = (row['end_time']-row['start_time']).seconds
        td_m, td_s = divmod(td_seconds, 60)
        if td_seconds == 0:
            continue
        str = f"{n+1}回目 {row['start_time'].strftime('%H:%M:%S')}-{row['end_time'].strftime('%H:%M:%S')} {td_m}m{td_s}s {row['situation']} {row['place']}({row['style']}) {row['quality']}{'野外排泄' if row['amount_field']>0 else ''} "
        if row['amount_omo'] > 50 :
            str += f"おもらし{row['amount_omo']:0.0f}+"
        elif row['amount_omo'] > 0 :
            str += f"ちびり{row['amount_omo']:0.0f}+"
        if (row['amount_out'] > 0):
            if (row['amount_field'] > 0):
                str += f"脱ぎかけ{row['amount_out']:.0f}+"
            else:
                str += f"便器外{row['amount_out']:.0f}+"
        if row['amount_field'] > 0 :
            str += f"{row['amount_field']:0.0f}g"
        else:
            str += f"{row['amount_toilet']:0.0f}g"

        print(str)
        f.write(str+'\n')
    
    